@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,9 +17,13 @@
 #ifndef BZF_ARC_OBSTACLE_H
 #define BZF_ARC_OBSTACLE_H
 
-#include "common.h"
-#include <string>
+// Inherits from
 #include "Obstacle.h"
+
+// System headers
+#include <string>
+
+// Common headers
 #include "MeshObstacle.h"
 #include "MeshTransform.h"
 #include "BzMaterial.h"
