@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,11 +17,9 @@
 #ifndef BZF_BASE_BUILDING_H
 #define BZF_BASE_BUILDING_H
 
-#include "common.h"
-#include <string>
-#include "Obstacle.h"
+#include "BoxBuilding.h"
 
-class BaseBuilding : public Obstacle
+class BaseBuilding : public BoxBuilding
 {
 
     friend class ObstacleModifier;
@@ -37,15 +35,7 @@ public:
     const char*     getType() const;
     static const char*  getClassName(); // const
 
-    bool        isFlatTop() const;
-
-    float       intersect(const Ray &) const;
-    void        getNormal(const float *p, float *n) const;
-    void        get3DNormal(const float* p, float* n) const;
-
     bool        inCylinder(const float* p, float radius, float height) const;
-    bool        inBox(const float* p, float angle,
-                      float halfWidth, float halfBreadth, float height) const;
     bool        inMovingBox(const float* oldP, float oldAngle,
                             const float *newP, float newAngle,
                             float halfWidth, float halfBreadth, float height) const;
@@ -53,12 +43,6 @@ public:
                            float halfWidth, float halfBreadth, float height,
                            float* plane) const;
 
-    bool        getHitNormal(const float *pos1, float azimuth1,
-                             const float *pos2, float azimuth2,
-                             float halfWidth, float halfBreadth,
-                             float height,
-                             float *normal) const;
-    void        getCorner(int index, float *pos) const;
     int         getTeam() const;
 
     int packSize() const;
@@ -70,9 +54,6 @@ public:
 
     std::string     userTextures[2];
 
-private:
-    void finalize();
-
 private:
     static const char*  typeName;
     int team;
