@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,7 +20,7 @@
 // Inherits from
 #include "SceneNode.h"
 
-// Commen headers
+// Common headers
 #include "OpenGLLight.h"
 
 class BillboardSceneNode : public SceneNode
@@ -67,11 +67,8 @@ protected:
         BillboardRenderNode(const BillboardSceneNode*);
         ~BillboardRenderNode();
         void        setColor(const GLfloat* rgba);
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
         void        setFrame(float u, float v);
         void        setFrameSize(float du, float dv);
     private:
