@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -50,11 +50,11 @@ public:
         invisible = _invisible;
     }
 
-    virtual void move(const GLfloat pos[3], const GLfloat forward[3]);
-    void        addLight(SceneRenderer&);
+    void move(const GLfloat pos[3], const GLfloat forward[3]);
+    void        addLight(SceneRenderer&) override;
 
-    void        notifyStyleChange();
-    void        addRenderNodes(SceneRenderer&);
+    void        notifyStyleChange() override;
+    void        addRenderNodes(SceneRenderer&) override;
 
 protected:
     bool        isSuper;
@@ -66,11 +66,8 @@ protected:
         ~BoltRenderNode();
         void        setColor(const GLfloat* rgba);
         void        setTextureColor(const GLfloat* rgba);
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
         void        setAnimation(int cu, int cv);
 
         void        renderGeoBolt();
