@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,8 +27,8 @@ public:
     EighthDBaseSceneNode(const float pos[3],
                          const float size[3], float rotation);
     ~EighthDBaseSceneNode();
-    void        notifyStyleChange();
-    void        addRenderNodes(SceneRenderer&);
+    void        notifyStyleChange() override;
+    void        addRenderNodes(SceneRenderer&) override;
 protected:
     class EighthDBaseRenderNode : public RenderNode
     {
@@ -37,11 +37,8 @@ protected:
                               const float pos[3],
                               const float size[3], float rotation);
         ~EighthDBaseRenderNode();
-        void        render();
-        const GLfloat * getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
     private:
         const EighthDBaseSceneNode *sceneNode;
         GLfloat corner[8][3];
