@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -28,8 +28,8 @@ public:
                         const float size[3], float rotation);
     ~EighthDPyrSceneNode();
 
-    void        notifyStyleChange();
-    void        addRenderNodes(SceneRenderer&);
+    void        notifyStyleChange() override;
+    void        addRenderNodes(SceneRenderer&) override;
 
 protected:
     class EighthDPyrRenderNode : public RenderNode
@@ -39,11 +39,8 @@ protected:
                              const float pos[3],
                              const float size[3], float rotation);
         ~EighthDPyrRenderNode();
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
     private:
         const EighthDPyrSceneNode* sceneNode;
         GLfloat     corner[5][3];
