@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -74,7 +74,7 @@ enum FlagStatus
 };
 
 /** This enum tells us if the flag type is droppable, and what happens to it
-    when it's droppped. */
+    when it's dropped. */
 enum FlagEndurance
 {
     /// permanent flag
@@ -140,6 +140,8 @@ public:
         getFlagMap()[flagAbbv] = this;
     }
 
+    ~FlagType();
+
     /** returns a label of flag name and abbreviation with the flag name
      * excentuating the abbreviation if relevant.
      */
