@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,13 +41,11 @@ protected:
     public:
         FlagWarpRenderNode(const FlagWarpSceneNode*);
         ~FlagWarpRenderNode();
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
     private:
         const FlagWarpSceneNode* sceneNode;
+        static float ring[12][2];
     };
     friend class FlagWarpRenderNode;
 
