@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -105,7 +105,6 @@ public:
     int getFaceCount() const;
     MeshFace* getFace(int face) const;
     const float* getPosition() const;
-    const float* getSize() const;
     bool useSmoothBounce() const;
     bool noClusters() const;
 
@@ -210,11 +209,6 @@ inline const float* MeshObstacle::getPosition() const
     return pos;
 }
 
-inline const float* MeshObstacle::getSize() const
-{
-    return size;
-}
-
 inline bool MeshObstacle::useSmoothBounce() const
 {
     return smoothBounce;
