@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -60,16 +60,12 @@ protected:
         {
             style = _style;
         }
-        void render();
-        void renderRadar();
-        void renderShadow();
+        void render() override;
+        void renderShadow() override;
         const GLfloat* getVertex(int i) const;
         const GLfloat (*getVertices() const)[3];
         int getVertexCount() const;
-        const GLfloat* getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        const GLfloat* getPosition() const override;
     private:
         void drawV() const; // draw with just vertices
         void drawVT() const; // draw with texcoords
