@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,7 +13,10 @@
 #ifndef _TRANSFORM_H_
 #define _TRANSFORM_H_
 
+//1st
+#include "common.h"
 
+// System headers
 #include <string>
 #include <vector>
 #include <iostream>
