@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -59,7 +59,7 @@ public:
         @param hwidth     Half the X size of the obstacle
         @param hbreadth   Half the Y size of the obstacle
         @param height     The Z size of the obstacle
-        @param drive      @c true if the obstacle is drivethtrough, i.e. tanks
+        @param drive      @c true if the obstacle is drivethrough, i.e. tanks
           can pass through it
         @param shoot      @c true if the obstacle is shootthrough, i.e. bullets
           can pass through it
