@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -86,11 +86,8 @@ protected:
         SphereLodRenderNode(const SphereLodSceneNode*);
         ~SphereLodRenderNode();
         void setLod(int lod);
-        void render();
-        const GLfloat* getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void render() override;
+        const GLfloat* getPosition() const override;
 
     private:
         const SphereLodSceneNode* sceneNode;
@@ -147,8 +144,8 @@ public:
                            int theta, int phi);
         ~FragmentRenderNode();
         const GLfloat*  getVertex() const;
-        void        render();
-        const GLfloat*  getPosition() const;
+        void        render() override;
+        const GLfloat*  getPosition() const override;
     private:
         const SphereBspSceneNode*   sceneNode;
         int     theta, phi;
@@ -193,11 +190,8 @@ protected:
         ~SphereBspRenderNode();
         void        setHighResolution(bool);
         void        setBaseIndex(int index);
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
     private:
         const SphereBspSceneNode* sceneNode;
         bool        highResolution;
@@ -216,7 +210,7 @@ private:
 /******************************************************************************/
 
 
-#endif // BZF_FLAG_SCENE_NODE_H
+#endif // BZF_SPHERE_SCENE_NODE_H
 
 // Local Variables: ***
 // mode: C++ ***
