@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,8 +17,10 @@
 #ifndef BZF_TANK_SCENE_NODE_H
 #define BZF_TANK_SCENE_NODE_H
 
-#include "common.h"
+// Inherits from
 #include "SceneNode.h"
+
+// Common headers
 #include "OpenGLLight.h"
 #include "TankGeometryMgr.h"
 
@@ -62,8 +64,8 @@ public:
 
     void        move(const GLfloat plane[4]);
 
-    void        notifyStyleChange();
-    void        addRenderNodes(SceneRenderer&);
+    void        notifyStyleChange() override;
+    void        addRenderNodes(SceneRenderer&) override;
     // Irix 7.2.1 and solaris compilers appear to have a bug.  if the
     // following declaration isn't public it generates an error when trying
     // to declare SphereFragmentSceneNode::FragmentRenderNode a friend in
@@ -79,11 +81,8 @@ public:
     public:
         IDLRenderNode(const TankIDLSceneNode*);
         ~IDLRenderNode();
-        void        render();
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        void        render() override;
+        const GLfloat* getPosition() const override;
     private:
         const TankIDLSceneNode* sceneNode;
         static const int    idlFaces[][5];
@@ -172,12 +171,9 @@ protected:
         void        setTankSize(TankGeometryEnums::TankSize);
         void        sortOrder(bool above, bool towards, bool left);
         void        setNarrowWithDepth(bool narrow);
-        const GLfloat*  getPosition() const
-        {
-            return sceneNode->getSphere();
-        }
+        const GLfloat* getPosition() const override;
 
-        void        render();
+        void        render() override;
         void        renderPart(TankGeometryEnums::TankPart part);
         void        renderParts();
         void        renderTopParts();
