@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,9 +12,14 @@
 #ifndef _TEXTURE_MANAGER_H
 #define _TEXTURE_MANAGER_H
 
+// 1st
+#include "common.h"
+
+// System headers
 #include <string>
 #include <map>
 
+// Common headers
 #include "OpenGLTexture.h"
 #include "Singleton.h"
 
