@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -21,10 +21,15 @@
 #ifndef WORLD_EVENT_MANAGER_H
 #define WORLD_EVENT_MANAGER_H
 
+// 1st
+#include "common.h"
+
+// System headers
 #include <map>
 #include <vector>
 #include <algorithm>
 
+// Common headers
 #include "bzfsAPI.h"
 
 // event handler callback
