@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,29 +13,20 @@
 #ifndef __BZFSDL_H__
 #define __BZFSDL_H__
 
+// 1st
+#include "common.h"
+
 /** this file contains headers necessary for SDL */
 
-#if defined(HAVE_SDL2)
-#  ifdef HAVE_SDL2_SDL_H
-#    include <SDL2/SDL.h>
-#    include <SDL2/SDL_thread.h>
-#    include <SDL2/SDL_stdinc.h>
-#  else // autotools adds an SDL-specific include path
-#    include "SDL.h"
-#    include "SDL_thread.h"
-#    include "SDL_stdinc.h"
-#  endif //HAVE_SDL_SDL_H
-#elif defined(HAVE_SDL)
-#  ifdef HAVE_SDL_SDL_H
-#    include <SDL/SDL.h>
-#    include <SDL/SDL_thread.h>
-#    include <SDL/SDL_getenv.h>
-#  else // autotools adds an SDL-specific include path
-#    include "SDL.h"
-#    include "SDL_thread.h"
-#    include "SDL_getenv.h"
-#  endif //HAVE_SDL_SDL_H
-#endif //HAVE_SDL
+#ifdef HAVE_SDL2_SDL_H
+#  include <SDL2/SDL.h>
+#  include <SDL2/SDL_thread.h>
+#  include <SDL2/SDL_stdinc.h>
+#else // autotools adds an SDL-specific include path
+#  include "SDL.h"
+#  include "SDL_thread.h"
+#  include "SDL_stdinc.h"
+#endif //HAVE_SDL_SDL_H
 
 #endif /* __BZFSDL_H__ */
 
