@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -43,12 +43,10 @@ public:
     void setTimeout(long timeout);
     void setNoBody();
     void setGetMode();
-    void setHTTPPostMode();
     void setPostMode(std::string postData);
     void setRequestFileTime(bool request);
     void setURL(const std::string &url);
-    void setURLwithNonce(const std::string &url);
-    void setProgressFunction(curl_progress_callback func, const void* data);
+    void setProgressFunction(curl_xferinfo_callback func, const void* data);
     void setTimeCondition(timeCondition condition, time_t &t);
     void setInterface(const std::string &interfaceIP);
     void setUserAgent(const std::string &userAgent);
@@ -57,7 +55,7 @@ public:
     void addFormData(const char *key, const char *value);
 
     bool getFileTime(time_t &t);
-    bool getFileSize(double &size);
+    bool getFileSize(int    &size);
 
     virtual void collectData(char *ptr, int len);
     virtual void finalization(char *data, unsigned int length, bool good);
@@ -84,9 +82,6 @@ private:
     std::string   userAgent;
     std::string   postData;
 
-    struct curl_httppost* formPost;
-    struct curl_httppost* formLast;
-
     static void   setup();
 
     static size_t writeFunction(void *ptr, size_t size, size_t nmemb,
