@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,7 +13,8 @@
 #ifndef __VERSION_H__
 #define __VERSION_H__
 
-#include "config.h"
+// 1st
+#include "common.h"
 
 #ifndef BZ_CONFIG_DIR_VERSION
 #define BZ_CONFIG_DIR_VERSION   "2.4"
@@ -24,7 +25,7 @@
 #endif
 
 #ifndef BZ_CONFIG_FILE_VERSION
-#define BZ_CONFIG_FILE_VERSION  5
+#define BZ_CONFIG_FILE_VERSION  6
 #endif
 
 #define BZ_CONNECT_HEADER   "BZFLAG\r\n\r\n"
