@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -192,12 +192,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
 
     option = new HUDuiList;
     option->setFontFace(fontFace);
-
-#if (defined(HAVE_SDL) && !defined(HAVE_SDL2))  // only SDL 2 can make live changes
-    option->setLabel("(restart required) Energy Saver:");
-#else
     option->setLabel("Energy Saver:");
-#endif
     option->setCallback(callback, "s");
     options = &option->getList();
     options->push_back(std::string("Off"));
@@ -476,7 +471,7 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
     case 'A':
     {
         int aniso = list->getIndex();
-        BZDB.setInt("aniso", (aniso == 0)?0:(int)pow(2, aniso));
+        BZDB.setInt("aniso", (int)pow(2, aniso));
         TextureManager& tm = TextureManager::instance();
         tm.setMaxFilter(tm.getMaxFilter());
         sceneRenderer->notifyStyleChange();
@@ -522,7 +517,7 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
     case 'm':
     {
         int multi = list->getIndex();
-        BZDB.setInt("multisample", (multi == 0)?0:(int)pow(2, multi));
+        BZDB.setInt("multisample", (int)pow(2, multi));
         break;
     }
     case 'g':
