@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -21,7 +21,7 @@
 #include "playing.h"
 
 static BzfJoystick*     getJoystick();
-static bool      useForceFeedback(const char *type = "Rumble");
+static bool      useForceFeedback();
 
 
 static BzfJoystick*     getJoystick()
@@ -33,7 +33,7 @@ static BzfJoystick*     getJoystick()
         return NULL;
 }
 
-static bool      useForceFeedback(const char *type)
+static bool      useForceFeedback()
 {
     BzfJoystick* js = getJoystick();
 
@@ -47,11 +47,8 @@ static bool      useForceFeedback(const char *type)
     if (LocalPlayer::getMyTank()->getInputMethod() != LocalPlayer::Joystick)
         return false;
 
-    /* Did the user enable force feedback of this type? */
-    if (BZDB.get("forceFeedback") != type)
-        return false;
-
-    return true;
+    /* Did the user enable rumble? */
+    return BZDB.isTrue("rumble");
 }
 
 namespace ForceFeedback
@@ -60,19 +57,15 @@ namespace ForceFeedback
 void death()
 {
     /* Nice long hard rumble for death */
-    if (useForceFeedback("Rumble"))
-        getJoystick()->ffRumble(1, 0.0f, 1.5f, 1.0f, 0.0f);
-    else if (useForceFeedback("Directional"))
-        getJoystick()->ffDirectionalPeriodic(1, 0.0f, 1.5f, 1.0f, 0.0f, 1.0f, 0.15f, BzfJoystick::FF_SawtoothDown);
+    if (useForceFeedback())
+        getJoystick()->ffRumble(1, 1.5f, 1.0f, 0.0f);
 }
 
 void shotFired()
 {
     /* Tiny little kick for a normal shot being fired */
-    if (useForceFeedback("Rumble"))
-        getJoystick()->ffRumble(1, 0.0f, 0.1f, 0.0f, 1.0f);
-    else if (useForceFeedback("Directional"))
-        getJoystick()->ffDirectionalConstant(1, 0.0f, 0.1f, 0.0f, -1.0f, 0.5f);
+    if (useForceFeedback())
+        getJoystick()->ffRumble(1, 0.1f, 0.0f, 1.0f);
 }
 
 void laserFired()
@@ -82,37 +75,15 @@ void laserFired()
      *  some quirks in its driver may mean it's feeling a little different
      *  than it should)
      */
-    if (useForceFeedback("Rumble"))
-        getJoystick()->ffRumble(4, 0.01f, 0.02f, 1.0f, 1.0f);
-    else if (useForceFeedback("Directional"))
-        getJoystick()->ffDirectionalPeriodic(4, 0.1f, 0.1f, 0.0f, -1.0f, 0.5f, 0.05f, BzfJoystick::FF_Sine);
+    if (useForceFeedback())
+        getJoystick()->ffRumble(4, 0.02f, 1.0f, 1.0f);
 }
 
 void shockwaveFired()
 {
     /* try to 'match' the shockwave sound */
-    if (useForceFeedback("Rumble"))
-        getJoystick()->ffRumble(1, 0.0f, 0.5f, 0.0f, 1.0f);
-    else if (useForceFeedback("Directional"))
-        getJoystick()->ffDirectionalPeriodic(1, 0.0f, 1.0f, 0.0f, -1.0f, 0.5f, 0.1f, BzfJoystick::FF_Sine);
-}
-
-/* Burrowed, oscillating, etc, tanks get a special resistance force
- * when moving through solid matter.  We use half-second increments
- * of force-on time.
- */
-static TimeKeeper friction_timer = TimeKeeper::getSunGenesisTime();
-void solidMatterFriction()
-{
-    /* There is no way to simulate this with a rumble effect */
-    if (useForceFeedback("Directional"))
-    {
-        if ((TimeKeeper::getCurrent() - friction_timer) >= 0.5f)
-        {
-            getJoystick()->ffDirectionalResistance(0.5f, 1.0f, 0.5f, BzfJoystick::FF_Position);
-            friction_timer = TimeKeeper::getCurrent();
-        }
-    }
+    if (useForceFeedback())
+        getJoystick()->ffRumble(1, 0.5f, 0.0f, 1.0f);
 }
 }
 
