@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,10 +38,10 @@ public:
     ~HUDuiTypeIn();
 
     void        setObfuscation(bool on);
-    int         getMaxLength() const;
+    size_t      getMaxLength() const;
     std::string     getString() const;
 
-    void        setMaxLength(int);
+    void        setMaxLength(size_t);
     void        setString(const std::string&);
     void        setEditing(bool _allowEdit);
     void        setColorFunc(TypeInColorFunc func)
@@ -55,9 +55,9 @@ protected:
     void        doRender();
 
 private:
-    int         maxLength;
+    size_t          maxLength;
     std::string     string;
-    int         cursorPos;
+    size_t          cursorPos;
     bool        allowEdit;
     bool        obfuscate;
     TypeInColorFunc colorFunc;
