@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -21,6 +21,7 @@
 /* local interface headers */
 #include "MenuDefaultKey.h"
 #include "KeyboardMapMenu.h"
+#include "JoystickTestMenu.h"
 #include "HUDuiControl.h"
 #include "HUDuiList.h"
 #include "HUDuiDefaultKey.h"
@@ -45,11 +46,13 @@ public:
     void fillJSOptions();
 
 private:
-    HUDuiControl*    keyMapping;
-    HUDuiList*       activeInput;
-    HUDuiList*       jsx;
-    HUDuiList*       jsy;
-    KeyboardMapMenu* keyboardMapMenu;
+    HUDuiControl*      keyMapping;
+    HUDuiList*         activeInput;
+    HUDuiList*         jsx;
+    HUDuiList*         jsy;
+    HUDuiControl*      joystickTest;
+    KeyboardMapMenu*   keyboardMapMenu;
+    JoystickTestMenu*  joystickTestMenu;
 };
 
 
