@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -142,11 +142,11 @@ void NewVersionMenu::execute()
 void NewVersionMenu::collectData(char* ptr, int len)
 {
     char buffer[128];
-    double size = 0;
+    int size = 0;
     getFileSize(size);
     cURLManager::collectData(ptr, len);
     byteTransferred += len;
-    snprintf(buffer, 128, "Downloading update: %d/%d KB", byteTransferred/1024, (int)size/1024);
+    snprintf(buffer, 128, "Downloading update: %d/%d KB", byteTransferred/1024, size/1024);
     ((HUDuiLabel*)status)->setString(buffer);
 }
 
