@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -495,6 +495,12 @@ void ScoreboardRenderer::renderScoreboard(void)
             setHuntState (HUNT_NONE);
         else
         {
+            if (huntPosition < 0)
+            {
+                huntPosition = numPlayers - 1;
+                if (players[huntPosition] == myTank)
+                    --huntPosition;
+            }
             if (players[huntPosition] == myTank)
             {
                 if (huntPositionEvent < 0)
