@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,8 +12,11 @@
 
 // Interface header
 #include "ShotStatistics.h"
+
+// Common headers
 #include "TimeKeeper.h"
 #include "playing.h"
+#include "mathRoutine.h"
 
 ShotStatistics::ShotStatistics() :
     totalFired(0), totalHit(0)
@@ -49,14 +52,16 @@ void ShotStatistics::recordFire(FlagType* flag, const float *pVec, const float *
     float playerMag,shotMag;
 
     playerMag = sqrt((pVec[0]*pVec[0])+(pVec[1]*pVec[1])+pVec[2]*pVec[2]);
-    shotMag = sqrt((shotVec[0]*shotVec[0])+(shotVec[1]*shotVec[1])+shotVec[2]*shotVec[2]);
+    shotMag = bzInverseSqrt(shotVec[0] * shotVec[0] +
+                            shotVec[1] * shotVec[1] +
+                            shotVec[2] * shotVec[2]);
 
     playerNorm[0] = pVec[0]/playerMag;
     playerNorm[1] = pVec[1]/playerMag;
     playerNorm[2] = pVec[2]/playerMag;
-    shotNorm[0] = shotVec[0]/shotMag;
-    shotNorm[1] = shotVec[1]/shotMag;
-    shotNorm[2] = shotVec[2]/shotMag;
+    shotNorm[0]   = shotVec[0] * shotMag;
+    shotNorm[1]   = shotVec[1] * shotMag;
+    shotNorm[2]   = shotVec[2] * shotMag;
 
     float dot = (shotNorm[0] * playerNorm[0]) + (shotNorm[1] * playerNorm[1]) + shotNorm[2] * playerNorm[2];
 
