@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -150,12 +150,12 @@ class TrackRenderNode : public RenderNode
 public:
     TrackRenderNode(const TrackEntry* te, TrackType type);
     ~TrackRenderNode();
-    void render();
-    void renderShadow()
+    void render() override;
+    void renderShadow() override
     {
         return;
     }
-    const GLfloat* getPosition() const
+    const GLfloat* getPosition() const override
     {
         return te->pos;
     }
@@ -735,6 +735,9 @@ static void drawPuddle(const TrackEntry& te)
 
 static void drawTreads(const TrackEntry& te)
 {
+    if (!TrackFadeTime)
+        return;
+
     const float ratio = (te.lifeTime / TrackFadeTime);
 
     glColor4f(0.0f, 0.0f, 0.0f, 1.0f - ratio);
