@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -247,14 +247,9 @@ void WorldBuilder::preGetWorld()
     // prepare players array
     if (world->players)
         delete[] world->players;
-    // FIXME
-    // world->maxPlayers do not work as bzfs uses more player slot than
-    // real players. Any tcp connection is assigned a slot.
-    // So I put now 216. We should fix it though.
-    const int maxPlayers = 216;
-    world->players = new RemotePlayer*[maxPlayers];
+    world->players = new RemotePlayer*[maxRemotePlayers];
     int i;
-    for (i = 0; i < maxPlayers; i++)
+    for (i = 0; i < maxRemotePlayers; i++)
         world->players[i] = NULL;
 
     // prepare flags array
