@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -45,6 +45,11 @@ DefaultDBItem defaultDBItems[] =
     { "radarsize",        "8",            true,   StateDatabase::ReadWrite,   NULL },
     { "mouseboxsize",     "5",            true,   StateDatabase::ReadWrite,   NULL },
     { "mouseClamp",       "0",            true,   StateDatabase::ReadWrite,   NULL },
+    { "jsInvertAxes",       "0",            true,   StateDatabase::ReadWrite,   NULL },
+    { "jsRangeMax",       "100",            true,   StateDatabase::ReadWrite,   NULL },
+    { "jsRangeMin",       "5",            true,   StateDatabase::ReadWrite,   NULL },
+    { "jsStretchCorners",       "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "jsRampType",       "linear",            true,   StateDatabase::ReadWrite,   NULL },
     { "cpanelfontsize",       "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "controlPanelTimestamp",    "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "scorefontsize",        "0",            true,   StateDatabase::ReadWrite,   NULL },
@@ -71,6 +76,7 @@ DefaultDBItem defaultDBItems[] =
     { "displayFOV",       "60.0",         false,  StateDatabase::ReadWrite,   NULL },
     { "roamZoomMax",      "120",          false,  StateDatabase::ReadWrite,   NULL },
     { "roamZoomMin",      "15",           false,  StateDatabase::ReadWrite,   NULL },
+    { "rumble",           "1",            true,  StateDatabase::ReadWrite,   NULL },
     { "maxQuality",       "3",            false,  StateDatabase::ReadWrite,   NULL },
     { "groundTexRepeat",      "0.1",          true,   StateDatabase::ReadWrite,   NULL },
     { "groundHighResTexRepeat",   "0.05",         true,   StateDatabase::ReadWrite,   NULL },
