@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,10 +13,15 @@
 #ifndef __ACCESSCONTROLLIST_H__
 #define __ACCESSCONTROLLIST_H__
 
+// 1st
+#include "common.h"
+
+// System headers
 #include <vector>
 #include <string>
 #include <string.h>
 
+// Common headers
 #include "TimeKeeper.h"
 #include "Address.h"
 
