@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -158,7 +158,7 @@ const char *extraUsageString =
     "BZFS Option Descriptions\n"
     "\n"
     "\t-a: maximum acceleration settings\n"
-    "\t-adminlagannounce: lag announcement threshhold time [ms]\n"
+    "\t-adminlagannounce: lag announcement threshold time [ms]\n"
     "\t-admsg: specify a <msg> which will be broadcast every 15 minutes\n"
     "\t-advertise: specify which groups to advertise to (list server)\n"
     "\t-autoTeam: automatically assign players to teams when they join\n"
@@ -189,14 +189,14 @@ const char *extraUsageString =
     "\t-i: listen on <interface>\n"
     "\t-j: allow jumping\n"
     "\t-jitterdrop: drop player after this many jitter warnings\n"
-    "\t-jitterwarn: jitter warning threshhold time [ms]\n"
-    "\t-lagannounce: lag announcement threshhold time [ms]\n"
+    "\t-jitterwarn: jitter warning threshold time [ms]\n"
+    "\t-lagannounce: lag announcement threshold time [ms]\n"
     "\t-lagdrop: drop player after this many lag warnings\n"
-    "\t-lagwarn: lag warning threshhold time [ms]\n"
+    "\t-lagwarn: lag warning threshold time [ms]\n"
     "\t-loadplugin: load the specified plugin with the specified commandline\n"
     "\t\tstring\n"
-    "\t-masterBanURL: URL to atempt to get the master ban list from <URL>\n"
-    "\t-maxidle: idle kick threshhold [s]\n"
+    "\t-masterBanURL: URL to attempt to get the master ban list from <URL>\n"
+    "\t-maxidle: idle kick threshold [s]\n"
     "\t-mp: maximum players total or per team\n"
     "\t-mps: set player score limit on each game\n"
     "\t-ms: maximum simultaneous shots per player\n"
@@ -204,7 +204,7 @@ const char *extraUsageString =
     "\t-noMasterBanlist: has public servers ignore the master ban list\n"
     "\t-noradar: disallow the use of radar\n"
     "\t-noTeamKills: Players on the same team are immune to each other's shots. Rogue is excepted.\n"
-    "\t-offa: teamless free-for-all game stye\n"
+    "\t-offa: teamless free-for-all game style\n"
     "\t-p: use alternative port (default=5154)\n"
     "\t-packetlossdrop: drop player after this many packetloss warnings\n"
     "\t-packetlosswarn: packetloss warning threshold [%]\n"
