@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -136,7 +136,7 @@ bool CustomCone::read(const char *cmd, std::istream& input)
 }
 
 
-void CustomCone::writeToGroupDef(GroupDefinition *groupdef) const
+void CustomCone::writeToGroupDef(GroupDefinition *groupdef)
 {
     int i;
     const BzMaterial* mats[MaterialCount];
