@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,8 +13,6 @@
 #ifndef __CUSTOMGATE_H__
 #define __CUSTOMGATE_H__
 
-#include "common.h"
-
 /* interface header */
 #include "WorldFileObstacle.h"
 
@@ -30,8 +28,8 @@ class CustomGate : public WorldFileObstacle
 {
 public:
     CustomGate(const char* telename);
-    virtual bool read(const char *cmd, std::istream&);
-    virtual void writeToGroupDef(GroupDefinition*) const;
+    bool read(const char *cmd, std::istream&) override;
+    void writeToGroupDef(GroupDefinition*) override;
 
 protected:
     std::string telename;
