@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -305,7 +305,7 @@ static void getEdgeLengths(const MeshTransform& xform, float lengths[6])
 }
 
 
-void CustomPyramid::writeToGroupDef(GroupDefinition *groupdef) const
+void CustomPyramid::writeToGroupDef(GroupDefinition *groupdef)
 {
     if (isOldPyramid && transform.isEmpty())
     {
