@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -14,6 +14,9 @@
 #ifndef __PARSE_MATERIAL_H__
 #define __PARSE_MATERIAL_H__
 
+// 1st
+#include "common.h"
+
 /* system interface headers */
 #include <iostream>
 
