@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -53,7 +53,7 @@ void WorldFileObject::writeToManager() const
 }
 
 
-void WorldFileObject::writeToGroupDef(GroupDefinition*) const
+void WorldFileObject::writeToGroupDef(GroupDefinition*)
 {
     std::cout << "ERROR: writeToGroupDef() called improperly" << std::endl;
     return;
