@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,6 +13,9 @@
 #ifndef __WORLD_GENERATORS_H__
 #define __WORLD_GENERATORS_H__
 
+// 1st
+#include "common.h"
+
 class WorldInfo;
 
 extern WorldInfo *defineTeamWorld();
