@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,7 +39,6 @@
 #include "BaseBuilding.h"
 #include "TetraBuilding.h"
 #include "Teleporter.h"
-#include "WallObstacle.h"
 #include "MeshObstacle.h"
 #include "ArcObstacle.h"
 #include "ConeObstacle.h"
@@ -76,15 +75,6 @@ WorldInfo::~WorldInfo()
     finished = false;
 }
 
-
-void WorldInfo::addWall(float x, float y, float z, float r, float w, float h)
-{
-    const float pos[3] = {x, y, z};
-    WallObstacle* wall = new WallObstacle(pos, r, w, h, false);
-    OBSTACLEMGR.addWorldObstacle(wall);
-}
-
-
 void WorldInfo::addLink(int src, int dst)
 {
     links.addLink(src, dst);
