@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -117,14 +117,14 @@ void BZDBint::callback()
 
     if (tmp < min)
     {
-        logDebugMessage(3,"BZDBint(%s) min: %f < %f\n", name.c_str(), tmp, min);
+        logDebugMessage(3,"BZDBint(%s) min: %i < %i\n", name.c_str(), tmp, min);
         tmp = min; // clamp to min
         safeSetInt(name, tmp);
     }
 
     if (tmp > max)
     {
-        logDebugMessage(3,"BZDBint(%s) max: %f > %f\n", name.c_str(), tmp, max);
+        logDebugMessage(3,"BZDBint(%s) max: %i > %i\n", name.c_str(), tmp, max);
         tmp = max; // clamp to max
         safeSetInt(name, tmp);
     }
