@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -236,27 +236,25 @@ void kill()
 
 void clearCustomFlags()
 {
-    FlagSet::iterator itr, nitr;
+    FlagSet::iterator itr;
     for (int q = 0; q < (int)NumQualities; ++q)
-    {
-        for (itr = FlagType::flagSets[q].begin(); itr != FlagType::flagSets[q].end(); ++itr)
-        {
+        for (itr = FlagType::flagSets[q].begin(); itr != FlagType::flagSets[q].end();)
             if ((*itr)->custom)
             {
-                FlagType::getFlagMap().erase((*itr)->flagAbbv);
-                nitr = itr;
-                ++nitr;
-                delete (*itr);
-                FlagType::flagSets[q].erase(itr);
-                itr = nitr;
-                if (itr == FlagType::flagSets[q].end()) break;
+                delete *itr;
+                itr = FlagType::flagSets[q].erase(itr);
             }
-        }
-    }
+            else
+                itr++;
     FlagType::customFlags.clear();
 }
 }
 
+FlagType::~FlagType()
+{
+    getFlagMap().erase(flagAbbv);
+}
+
 void* FlagType::pack(void* buf) const
 {
     buf = nboPackUByte(buf, (flagAbbv.size() > 0) ? flagAbbv[0] : 0);
@@ -292,8 +290,7 @@ void* FlagType::packCustom(void* buf) const
 
 const void* FlagType::unpackCustom(const void* buf, FlagType* &type)
 {
-    uint8_t *abbv = new uint8_t[3];
-    abbv[0]=abbv[1]=abbv[2]=0;
+    unsigned char abbv[3] = {0, 0, 0};
     buf = nboUnpackUByte(buf, abbv[0]);
     buf = nboUnpackUByte(buf, abbv[1]);
 
@@ -319,7 +316,7 @@ const void* FlagType::unpackCustom(const void* buf, FlagType* &type)
         assert(false); // shouldn't happen
     }
 
-    type = new FlagType(sName, reinterpret_cast<const char*>(&abbv[0]),
+    type = new FlagType(sName, (char *)abbv,
                         e, (ShotType)shot, (FlagQuality)quality, NoTeam, sHelp, true);
     return buf;
 }
