@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -37,9 +37,6 @@ cURLManager::cURLManager()
     theLen    = 0;
     added     = false;
 
-    formPost  = NULL;
-    formLast  = NULL;
-
     if (!inited)
         setup();
 
@@ -171,15 +168,6 @@ void cURLManager::setPostMode(std::string _postData)
         logDebugMessage(1,"CURLOPT_POST error %d : %s\n", result, errorBuffer);
 }
 
-void cURLManager::setHTTPPostMode()
-{
-    CURLcode result;
-
-    result = curl_easy_setopt(easyHandle, CURLOPT_HTTPPOST, formPost);
-    if (result != CURLE_OK)
-        logDebugMessage(1,"CURLOPT_HTTPPOST error %d : %s\n", result, errorBuffer);
-}
-
 void cURLManager::setURL(const std::string &url)
 {
     CURLcode result;
@@ -198,22 +186,14 @@ void cURLManager::setURL(const std::string &url)
         logDebugMessage(1,"CURLOPT_URL error %d : %s\n", result, errorBuffer);
 }
 
-void cURLManager::setURLwithNonce(const std::string &url)
-{
-    // only the default list server is known to support the nonce parameter
-    const std::string nonce = (strcasecmp(url.c_str(), DefaultListServerURL) == 0) ? TextUtils::format("?nocache=%lu",
-                              time(0)) : "";
-    setURL(url + nonce);
-}
-
-void cURLManager::setProgressFunction(curl_progress_callback func, const void* data)
+void cURLManager::setProgressFunction(curl_xferinfo_callback func, const void* data)
 {
     CURLcode result;
     if (func != NULL)
     {
-        result = curl_easy_setopt(easyHandle, CURLOPT_PROGRESSFUNCTION, func);
+        result = curl_easy_setopt(easyHandle, CURLOPT_XFERINFOFUNCTION, func);
         if (result == CURLE_OK)
-            result = curl_easy_setopt(easyHandle, CURLOPT_PROGRESSDATA, data);
+            result = curl_easy_setopt(easyHandle, CURLOPT_XFERINFODATA, data);
         if (result == CURLE_OK)
             result = curl_easy_setopt(easyHandle, CURLOPT_NOPROGRESS, 0);
     }
@@ -336,12 +316,6 @@ void cURLManager::infoComplete(CURLcode result)
     if (result != CURLE_OK)
         logDebugMessage(1,"File transfer terminated with error from libcurl %d : %s\n",
                         result, errorBuffer);
-    if (formPost)
-    {
-        curl_formfree(formPost);
-        formPost = NULL;
-        formLast = NULL;
-    }
     removeHandle();
     finalization((char *)theData, theLen, result == CURLE_OK);
     justCalled = true;
@@ -364,13 +338,15 @@ bool cURLManager::getFileTime(time_t &t)
     return true;
 }
 
-bool cURLManager::getFileSize(double &size)
+bool cURLManager::getFileSize(int &size)
 {
     CURLcode result;
-    result = curl_easy_getinfo(easyHandle, CURLINFO_SIZE_DOWNLOAD, &size);
+    curl_off_t mySize;
+    result = curl_easy_getinfo(easyHandle, CURLINFO_SIZE_DOWNLOAD_T, &mySize);
+    size = (int)mySize;
     if (result)
     {
-        logDebugMessage(1,"CURLINFO_SIZE_DOWNLOAD error %d : %s\n", result, errorBuffer);
+        logDebugMessage(1,"CURLINFO_SIZE_DOWNLOAD_T error %d : %s\n", result, errorBuffer);
         return false;
     }
     return true;
@@ -432,18 +408,6 @@ void cURLManager::setUserAgent(const std::string &_userAgent)
         logDebugMessage(1,"CURLOPT_SET_USERAGENT error %d : %s\n", result, errorBuffer);
 }
 
-void cURLManager::addFormData(const char *key, const char *value)
-{
-    CURLFORMcode result;
-    result = curl_formadd(&formPost, &formLast,
-                          CURLFORM_COPYNAME, key,
-                          CURLFORM_COPYCONTENTS, value,
-                          CURLFORM_CONTENTSLENGTH, strlen(value),
-                          CURLFORM_END);
-    if (result != CURL_FORMADD_OK)
-        logDebugMessage(1,"addFormData error %d : %s\n", result, errorBuffer);
-}
-
 void cURLManager::setDNSCachingTime(long time)
 {
     CURLcode result;
