@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -48,7 +48,7 @@
 #endif
 
 #ifndef BZ_REV
-#  define BZ_REV        26
+#  define BZ_REV        30
 #endif
 
 // DEVEL | RC# | STABLE | MAINT
@@ -56,7 +56,7 @@
 #  define BZ_BUILD_TYPE     "MAINT"
 #endif
 
-const char *bzfcopyright = "Copyright (c) 1993-2021 Tim Riker";
+const char *bzfcopyright = "Copyright (c) 1993-2025 Tim Riker";
 
 static int getBuildDate()
 {
@@ -143,13 +143,8 @@ const char*     getAppVersion()
         std::ostringstream  appVersionStream;
         // TODO add current platform, release, cpu, etc
         appVersionStream << getMajorMinorRevVersion() << "." << getBuildDate()
-                         << "-" << BZ_BUILD_TYPE << "-" << BZ_BUILD_OS;
-#ifdef HAVE_SDL
-        appVersionStream << "-SDL";
-#ifdef HAVE_SDL2
-        appVersionStream << "2";
-#endif
-#endif
+                         << "-" << BZ_BUILD_TYPE << "-" << BZ_BUILD_OS
+                         << "-SDL2";
         appVersion = appVersionStream.str();
     }
     return appVersion.c_str();
