@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -247,6 +247,11 @@ BoltSceneNode::BoltRenderNode::~BoltRenderNode()
     // do nothing
 }
 
+const GLfloat* BoltSceneNode::BoltRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
+
 void            BoltSceneNode::BoltRenderNode::setAnimation(
     int _cu, int _cv)
 {
@@ -636,7 +641,7 @@ void            BoltSceneNode::BoltRenderNode::render()
                 const float ti = theta[i];
                 const float fs = FlareSpread;
                 glBegin(GL_TRIANGLE_STRIP);
-                glVertex3fv(core[0]);
+                glVertex3f(0.0f,                0.0f,                0.0f);
                 glVertex3f(c * cosf(ti - fs),   c * sinf(ti - fs),   s);
                 glVertex3f(c * cosf(ti + fs),   c * sinf(ti + fs),   s);
                 glVertex3f(c * cosf(ti) * 2.0f, c * sinf(ti) * 2.0f, s * 2.0f);
