@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -134,6 +134,11 @@ EighthDBoxSceneNode::EighthDBoxRenderNode::~EighthDBoxRenderNode()
     // do nothing
 }
 
+const GLfloat* EighthDBoxSceneNode::EighthDBoxRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
+
 void            EighthDBoxSceneNode::EighthDBoxRenderNode::render()
 {
     myColor3f(1.0f, 1.0f, 1.0f);
