@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -93,6 +93,11 @@ EighthDimSceneNode::EighthDimRenderNode::~EighthDimRenderNode()
     delete[] poly;
 }
 
+const GLfloat* EighthDimSceneNode::EighthDimRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
+
 void            EighthDimSceneNode::EighthDimRenderNode::render()
 {
     // draw polygons
