@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -123,6 +123,10 @@ EighthDimShellNode::ShellRenderNode::~ShellRenderNode()
     return;
 }
 
+const GLfloat* EighthDimShellNode::ShellRenderNode::getPosition() const
+{
+    return renderNode->getPosition();
+}
 
 const OpenGLGState* EighthDimShellNode::ShellRenderNode::getGState() const
 {
@@ -160,6 +164,10 @@ void EighthDimShellNode::ShellRenderNode::render()
     return;
 }
 
+void EighthDimShellNode::ShellRenderNode::renderShadow()
+{
+}
+
 
 // Local Variables: ***
 // mode: C++ ***
