@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -77,8 +77,8 @@ private:
     float ripple2;
 
     GLuint glList;
-    GLfloat verts[(maxChunks + 1) * 2][3];
-    GLfloat txcds[(maxChunks + 1) * 2][2];
+    GLfloat verts[maxChunks * 2][3];
+    GLfloat txcds[maxChunks * 2][2];
 };
 
 
