@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,7 +23,7 @@
 // FIXME (SceneRenderer.cxx is in src/bzflag)
 #include "SceneRenderer.h"
 
-// FIXME - no tesselation is done on for shot lighting
+// FIXME - no tessellation is done on for shot lighting
 
 
 //
@@ -48,6 +48,11 @@ MeshPolySceneNode::Geometry::~Geometry()
     return;
 }
 
+const GLfloat*  MeshPolySceneNode::Geometry::getPosition() const
+{
+    return sceneNode->getSphere();
+}
+
 inline void MeshPolySceneNode::Geometry::drawV() const
 {
     const int count = vertices.getSize();
@@ -127,14 +132,6 @@ void MeshPolySceneNode::Geometry::render()
 }
 
 
-void MeshPolySceneNode::Geometry::renderRadar()
-{
-    drawV();
-    addTriangleCount(vertices.getSize() - 2);
-    return;
-}
-
-
 void MeshPolySceneNode::Geometry::renderShadow()
 {
     drawV();
