@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -45,7 +45,7 @@
 // NOTE
 //
 //   This type of SceneNode does not support
-//   tesselation or splitting of translucent
+//   tessellation or splitting of translucent
 //   nodes for improved back-to-front sorting.
 //
 
@@ -177,6 +177,9 @@ MeshSceneNode::~MeshSceneNode()
     }
     delete[] lods;
 
+    delete [] lodLengths;
+    delete [] radarLengths;
+
     OpenGLGState::unregisterContextInitializer(freeContext, initContext, this);
 
     return;
