@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -41,6 +41,11 @@ PolyWallSceneNode::Geometry::~Geometry()
     // do nothing
 }
 
+const GLfloat* PolyWallSceneNode::Geometry::getPosition() const
+{
+    return wall->getSphere();
+}
+
 void            PolyWallSceneNode::Geometry::render()
 {
     wall->setColor();
