@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -240,8 +240,8 @@ SphereLodSceneNode::SphereLodSceneNode(const GLfloat pos[3], GLfloat _radius) :
     OpenGLGStateBuilder builder(gstate);
     builder.setCulling(GL_BACK);
     builder.setShading(GL_SMOOTH);
-    const float spec[4] = {1.0f, 1.0f, 1.0f, 1.0f};
-    const float emis[4] = {0.0f, 0.0f, 0.0f, 0.0f};
+    const float spec[3] = {1.0f, 1.0f, 1.0f};
+    const float emis[3] = {0.0f, 0.0f, 0.0f};
     OpenGLMaterial glmat(spec, emis, 64.0f);
     builder.setMaterial(glmat);
     gstate = builder.getState();
@@ -330,6 +330,10 @@ SphereLodSceneNode::SphereLodRenderNode::~SphereLodRenderNode()
     return;
 }
 
+const GLfloat* SphereLodSceneNode::SphereLodRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
 
 void SphereLodSceneNode::SphereLodRenderNode::setLod(int _lod)
 {
@@ -598,6 +602,11 @@ SphereBspSceneNode::SphereBspRenderNode::~SphereBspRenderNode()
     // do nothing
 }
 
+const GLfloat* SphereBspSceneNode::SphereBspRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
+
 void            SphereBspSceneNode::SphereBspRenderNode::
 setHighResolution(bool _highResolution)
 {
