@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -424,7 +424,7 @@ void TankSceneNode::setJumpJets(float scale)
 }
 
 
-void TankSceneNode::setClipPlane(const float _plane[])
+void TankSceneNode::setClipPlane(const float _plane[4])
 {
     clip = true;
     clipPlane[0] = GLdouble(_plane[0]);
@@ -485,11 +485,12 @@ void TankSceneNode::rebuildExplosion()
 
         // cheezy spheroid explosion pattern
         const float vhMax = maxExplosionVel;
-        const float vhMag = vhMax * sinf((float)(M_PI * 0.5 * bzfrand()));
+        const float vhAng = (float)(M_PI * 0.5 * bzfrand());
+        const float vhMag = vhMax * sinf(vhAng);
+        const float vz    = vhMax * cosf(vhAng);
         const float vhAngle = (float)(2.0 * M_PI * bzfrand());
         vel[i][0] = cosf(vhAngle) * vhMag;
         vel[i][1] = sinf(vhAngle) * vhMag;
-        const float vz = sqrtf(fabsf((vhMax*vhMax) - (vhMag*vhMag)));
         vel[i][2] = vz * vertExplosionRatio; // flatten it a little
         if (bzfrand() > 0.5)
             vel[i][2] = -vel[i][2];
@@ -733,6 +734,10 @@ TankIDLSceneNode::IDLRenderNode::~IDLRenderNode()
     return;
 }
 
+const GLfloat* TankIDLSceneNode::IDLRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
 
 void TankIDLSceneNode::IDLRenderNode::render()
 {
@@ -867,6 +872,10 @@ TankSceneNode::TankRenderNode::~TankRenderNode()
     return;
 }
 
+const GLfloat* TankSceneNode::TankRenderNode::getPosition() const
+{
+    return sceneNode->getSphere();
+}
 
 void TankSceneNode::TankRenderNode::setRadar(bool radar)
 {
