@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -112,6 +112,11 @@ TriWallSceneNode::Geometry::~Geometry()
 #define EMITV(_i)   glVertex3fv(vertex[_i])
 #define EMITVT(_i)  glTexCoord2fv(uv[_i]); glVertex3fv(vertex[_i])
 
+const GLfloat* TriWallSceneNode::Geometry::getPosition() const
+{
+    return wall->getSphere();
+}
+
 void            TriWallSceneNode::Geometry::render()
 {
     wall->setColor();
