@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,8 +16,10 @@
 /* system implementation headers */
 #include <cerrno>
 #include <cstring>
+#include <mutex>
 
 bool AresHandler::globallyInited = false;
+std::mutex callback_mutex;
 
 AresHandler::AresHandler(int _index)
     : index(_index), status(None)
@@ -28,7 +30,15 @@ AresHandler::AresHandler(int _index)
     /* ask for local "hosts" lookups too */
     static char lookups[] = "fb";
     struct ares_options opts;
+    memset(&opts, 0, sizeof(opts));
+    int    flags = 0;
+
     opts.lookups = lookups;
+    flags       |= ARES_OPT_LOOKUPS;
+#if ARES_VERSION_MAJOR > 1 || ARES_VERSION_MINOR >= 26
+    opts.evsys   = ARES_EVSYS_DEFAULT;
+    flags       |= ARES_OPT_EVENT_THREAD;
+#endif
 
     /* start up our resolver */
     if (!globallyInited)
@@ -42,7 +52,7 @@ AresHandler::AresHandler(int _index)
     }
 
     /* start up our resolver */
-    int code = ares_init_options (&aresChannel, &opts, ARES_OPT_LOOKUPS);
+    int code = ares_init_options (&aresChannel, &opts, flags);
     aresFailed = (code != ARES_SUCCESS);
     if (aresFailed)
     {
@@ -62,9 +72,7 @@ bool AresHandler::globalInit()
 {
     if (!globallyInited)
     {
-#ifdef HAVE_ARES_LIBRARY_INIT
         if (ares_library_init(ARES_LIB_INIT_ALL) == ARES_SUCCESS)
-#endif
             globallyInited = true;
     }
     return globallyInited;
@@ -72,10 +80,8 @@ bool AresHandler::globalInit()
 
 void AresHandler::globalShutdown()
 {
-#ifdef HAVE_ARES_LIBRARY_INIT
     if (globallyInited)
         ares_library_cleanup();
-#endif
 }
 
 void AresHandler::queryHostname(const struct sockaddr *clientAddr)
@@ -110,17 +116,22 @@ void AresHandler::queryHost(const char *name)
 
     // launch the asynchronous query to look up this hostname
     status = HbNPending;
+
+#if HAVE_ARES_GETADDRINFO
+    struct ares_addrinfo_hints hints;
+    memset(&hints, 0, sizeof(hints));
+    hints.ai_family = AF_INET;
+
+    ares_getaddrinfo(aresChannel, name, NULL, &hints, staticCallbackAddrInfo,
+                     (void *)this);
+#else
     ares_gethostbyname(aresChannel, name, AF_INET, staticCallback,
                        (void *)this);
+#endif
 }
 
-#if ARES_VERSION_MAJOR >= 1 && ARES_VERSION_MINOR >= 5
 void AresHandler::staticCallback(void *arg, int callbackStatus,
                                  int, struct hostent *hostent)
-#else
-void AresHandler::staticCallback(void *arg, int callbackStatus,
-                                 struct hostent *hostent)
-#endif
 {
     ((AresHandler *)arg)->callback(callbackStatus, hostent);
 }
@@ -129,6 +140,9 @@ void AresHandler::callback(int callbackStatus, struct hostent *hostent)
 {
     if (callbackStatus == ARES_EDESTRUCTION)
         return;
+
+    const std::lock_guard<std::mutex> lock(callback_mutex);
+
     if (callbackStatus != ARES_SUCCESS)
     {
         logDebugMessage(1,"Player [%d] failed to resolve: error %d\n", index,
@@ -137,7 +151,7 @@ void AresHandler::callback(int callbackStatus, struct hostent *hostent)
     }
     else if (status == HbAPending)
     {
-        hostName = strdup(hostent->h_name);
+        hostName = hostent->h_name;
         status = HbASucceeded;
         logDebugMessage(2,"Player [%d] resolved to %s\n", index, hostName.c_str());
     }
@@ -148,19 +162,67 @@ void AresHandler::callback(int callbackStatus, struct hostent *hostent)
     }
 }
 
+#if HAVE_ARES_GETADDRINFO
+void AresHandler::staticCallbackAddrInfo(void *arg, int status,
+        int, struct ares_addrinfo *result)
+{
+    if (status == ARES_EDESTRUCTION)
+        return;
+
+    ((AresHandler *)arg)->callbackAddrInfo(status, result);
+}
+
+void AresHandler::callbackAddrInfo(int callbackStatus, struct ares_addrinfo *result)
+{
+    const std::lock_guard<std::mutex> lock(callback_mutex);
+
+    if (callbackStatus != ARES_SUCCESS)
+    {
+        logDebugMessage(1,"Player [%d] failed to resolve: error %d\n", index,
+                        callbackStatus);
+        status = Failed;
+    }
+    else if (status == HbNPending)
+    {
+        memcpy(&hostAddress,
+               &((sockaddr_in *)result->nodes->ai_addr)->sin_addr,
+               sizeof(hostAddress));
+        status = HbNSucceeded;
+    }
+}
+#endif
+
 const char *AresHandler::getHostname()
 {
-    return hostName.c_str();
+    if (!callback_mutex.try_lock())
+        return "";
+    const char *host = hostName.c_str();
+    callback_mutex.unlock();
+    return host;
 }
 
 AresHandler::ResolutionStatus AresHandler::getHostAddress(struct in_addr
         *clientAddr)
 {
+    if (!callback_mutex.try_lock())
+        return HbNPending;
+
+    const ResolutionStatus oldStatus = status;
     if (status == HbNSucceeded)
         memcpy(clientAddr, &hostAddress, sizeof(hostAddress));
-    return status;
+    callback_mutex.unlock();
+
+    return oldStatus;
 }
 
+#if ARES_VERSION_MAJOR > 1 || ARES_VERSION_MINOR >= 26
+void AresHandler::setFd(fd_set *, fd_set *, int &)
+{
+}
+void AresHandler::process(fd_set *, fd_set *)
+{
+}
+#else
 void AresHandler::setFd(fd_set *read_set, fd_set *write_set, int &maxFile)
 {
     if (aresFailed)
@@ -176,6 +238,7 @@ void AresHandler::process(fd_set *read_set, fd_set *write_set)
         return;
     ares_process(aresChannel, read_set, write_set);
 }
+#endif
 
 // Local Variables: ***
 // mode: C++ ***
