@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -40,17 +40,10 @@ ArcObstacle::ArcObstacle(const MeshTransform& xform,
                          float _rotation, float _sweepAngle, float _ratio,
                          const float _texsize[4], bool _useNormals,
                          int _divisions, const BzMaterial* mats[MaterialCount],
-                         int physics, bool bounce, bool drive, bool shoot, bool rico)
+                         int physics, bool bounce, bool drive, bool shoot,
+                         bool rico) :
+    Obstacle(_pos, _rotation, _size[0], _size[1], _size[2], drive, shoot, rico)
 {
-    // common obstace parameters
-    memcpy(pos, _pos, sizeof(pos));
-    memcpy(size, _size, sizeof(size));
-    angle = _rotation;
-    ZFlip = false;
-    driveThrough = drive;
-    shootThrough = shoot;
-    ricochet = rico;
-
     // arc specific parameters
     transform = xform;
     divisions = _divisions;
