@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,11 +27,9 @@ BaseBuilding::BaseBuilding()
 
 BaseBuilding::BaseBuilding(const float *p, float rotation,
                            const float *_size, int _team, bool rico) :
-    Obstacle(p, rotation, _size[0], _size[1], _size[2], false, false, rico),
+    BoxBuilding(p, rotation, _size[0], _size[1], _size[2], false, false, rico),
     team(_team)
 {
-    finalize();
-    return;
 }
 
 BaseBuilding::~BaseBuilding()
@@ -39,12 +37,6 @@ BaseBuilding::~BaseBuilding()
     // do nothing
 }
 
-void BaseBuilding::finalize()
-{
-    Obstacle::setExtents();
-    return;
-}
-
 Obstacle* BaseBuilding::copyWithTransform(const MeshTransform& xform) const
 {
     float newPos[3], newSize[3], newAngle;
@@ -71,36 +63,6 @@ const char*     BaseBuilding::getClassName()
     return typeName;
 }
 
-float           BaseBuilding::intersect(const Ray &r) const
-{
-    return timeRayHitsBlock(r, getPosition(), getRotation(),
-                            getWidth(), getBreadth(), getHeight());
-}
-
-void            BaseBuilding::getNormal(const float *p, float *n) const
-{
-    getNormalRect(p, getPosition(), getRotation(), getWidth(), getBreadth(), n);
-}
-
-void            BaseBuilding::get3DNormal(const float* p, float* n) const
-{
-    // This bit of cruft causes bullets to bounce of buildings in the z direction
-    if (fabs(p[2] - getPosition()[2]) < Epsilon)
-    {
-        n[0] = 0.0f;
-        n[1] = 0.0f;
-        n[2] = -1.0f;
-    }
-    else if (fabs(p[2] - (getPosition()[2] + getHeight())) < Epsilon)
-    {
-        n[0] = 0.0f;
-        n[1] = 0.0f;
-        n[2] = 1.0f;
-    } // end cruftiness
-    else
-        getNormal(p, n);
-}
-
 bool            BaseBuilding::inCylinder(const float *p, float radius, float height) const
 {
     return (p[2] < (getPosition()[2] + getHeight()))
@@ -108,42 +70,16 @@ bool            BaseBuilding::inCylinder(const float *p, float radius, float hei
            &&     testRectCircle(getPosition(), getRotation(), getWidth(), getBreadth(), p, radius);
 }
 
-bool            BaseBuilding::inBox(const float *p, float _angle,
-                                    float dx, float dy, float height) const
-{
-    return (p[2] < (getPosition()[2] + getHeight()))
-           &&     ((p[2]+height) >= getPosition()[2])
-           &&     testRectRect(getPosition(), getRotation(), getWidth(), getBreadth(),
-                               p, _angle, dx, dy);
-}
-
 bool            BaseBuilding::inMovingBox(const float* oldP, float,
         const float *p, float _angle,
         float dx, float dy, float height) const
 {
-    float topBaseHeight = getPosition()[2] + getHeight();
-    float higherZ;
-    float lowerZ;
     // if a base is just the ground (z == 0 && height == 0) no collision
     // ground is already handled
-    if (topBaseHeight <= 0.0)
+    if (!getPosition()[2] && !getHeight())
         return false;
-    if (oldP[2] > p[2])
-    {
-        higherZ = oldP[2];
-        lowerZ  = p[2];
-    }
-    else
-    {
-        higherZ = p[2];
-        lowerZ  = oldP[2];
-    }
-    if (lowerZ >= topBaseHeight)
-        return false;
-    if ((higherZ + height) < getPosition()[2])
-        return false;
-    return testRectRect(getPosition(), getRotation(), getWidth(), getBreadth(),
-                        p, _angle, dx, dy);
+
+    return BoxBuilding::inMovingBox(oldP, 0.0f, p, _angle, dx, dy, height);
 }
 
 bool            BaseBuilding::isCrossing(const float *p, float _angle,
@@ -187,70 +123,16 @@ bool            BaseBuilding::isCrossing(const float *p, float _angle,
     return true;
 }
 
-bool            BaseBuilding::getHitNormal(const float *pos1, float azimuth1,
-        const float *pos2, float azimuth2,
-        float halfWidth, float halfBreadth, float,
-        float *normal) const
-{
-    return Obstacle::getHitNormal(pos1, azimuth1, pos2, azimuth2, halfWidth, halfBreadth,
-                                  getPosition(), getRotation(), getWidth(), getBreadth(),
-                                  getHeight(), normal) >= 0.0f;
-}
-
-void            BaseBuilding::getCorner(int index, float *_pos) const
-{
-    const float *base = getPosition();
-    const float c = cosf(getRotation());
-    const float s = sinf(getRotation());
-    const float w = getWidth();
-    const float b = getBreadth();
-    switch (index & 3)
-    {
-    case 0:
-        _pos[0] = base[0] + c * w - s * b;
-        _pos[1] = base[1] + s * w + c * b;
-        break;
-    case 1:
-        _pos[0] = base[0] - c * w - s * b;
-        _pos[1] = base[1] - s * w + c * b;
-        break;
-    case 2:
-        _pos[0] = base[0] - c * w + s * b;
-        _pos[1] = base[1] - s * w - c * b;
-        break;
-    case 3:
-        _pos[0] = base[0] + c * w + s * b;
-        _pos[1] = base[1] + s * w - c * b;
-        break;
-    }
-    _pos[2] = base[2];
-    if (index >= 4) _pos[2] += getHeight();
-}
-
 int BaseBuilding::getTeam() const
 {
     return team;
 }
 
-bool            BaseBuilding::isFlatTop() const
-{
-    return true;
-}
-
-
 void* BaseBuilding::pack(void* buf) const
 {
     buf = nboPackUShort(buf, (uint16_t) team);
 
-    buf = nboPackVector(buf, pos);
-    buf = nboPackFloat(buf, angle);
-    buf = nboPackVector(buf, size);
-
-    unsigned char stateByte = 0;
-    stateByte |= isDriveThrough() ? _DRIVE_THRU : 0;
-    stateByte |= isShootThrough() ? _SHOOT_THRU : 0;
-    stateByte |= canRicochet()    ? _RICOCHET   : 0;
-    buf = nboPackUByte(buf, stateByte);
+    buf = BoxBuilding::pack(buf);
 
     return buf;
 }
@@ -262,17 +144,7 @@ const void* BaseBuilding::unpack(const void* buf)
     buf = nboUnpackUShort(buf, shortTeam);
     team = (int)shortTeam;
 
-    buf = nboUnpackVector(buf, pos);
-    buf = nboUnpackFloat(buf, angle);
-    buf = nboUnpackVector(buf, size);
-
-    unsigned char stateByte;
-    buf = nboUnpackUByte(buf, stateByte);
-    driveThrough = (stateByte & _DRIVE_THRU) != 0;
-    shootThrough = (stateByte & _SHOOT_THRU) != 0;
-    ricochet     = (stateByte & _RICOCHET)   != 0;
-
-    finalize();
+    buf = BoxBuilding::unpack(buf);
 
     return buf;
 }
@@ -282,10 +154,7 @@ int BaseBuilding::packSize() const
 {
     int fullSize = 0;
     fullSize += sizeof(uint16_t); // team
-    fullSize += sizeof(float[3]); // pos
-    fullSize += sizeof(float);    // rotation
-    fullSize += sizeof(float[3]); // size
-    fullSize += sizeof(uint8_t);  // state bits
+    fullSize += BoxBuilding::packSize();
     return fullSize;
 }
 
