@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -237,8 +237,11 @@ void Obstacle::addInsideSceneNode(SceneNode* node)
 {
     insideNodeCount++;
     SceneNode** tmp = new SceneNode*[insideNodeCount];
-    memcpy(tmp, insideNodes, (insideNodeCount - 1) * sizeof(SceneNode*));
-    delete[] insideNodes;
+    if (insideNodes)
+    {
+        memcpy(tmp, insideNodes, (insideNodeCount - 1) * sizeof(SceneNode*));
+        delete[] insideNodes;
+    }
     insideNodes = tmp;
     insideNodes[insideNodeCount - 1] = node;
 }
