@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -1362,8 +1362,6 @@ void OpenGLGState::initContext()
     glLoadIdentity();
     glEnable(GL_SCISSOR_TEST);
     glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
-    glPixelStorei(GL_UNPACK_ALIGNMENT,1);
-    glPixelStorei(GL_PACK_ALIGNMENT,1);
 }
 
 
@@ -1388,6 +1386,9 @@ void OpenGLGState::initGLState()
     glEnableClientState(GL_VERTEX_ARRAY);
     glEnableClientState(GL_NORMAL_ARRAY);
     glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+    glPixelStorei(GL_UNPACK_ALIGNMENT,1);
+    glPixelStorei(GL_PACK_ALIGNMENT,1);
 }
 
 // utility to check if an OpenGL extension is supported on this system
@@ -1693,22 +1694,8 @@ void bzMatrixMode(GLenum mode)
 
 #endif // DEBUG_GL_MATRIX_STACKS
 
-
-#if defined(_WIN32)
-#  define GET_CURRENT_CONTEXT wglGetCurrentContext
-#elif defined(__BEOS__)
-// no way to do that, and you shouldn't have to anyway!
-#  define GET_CURRENT_CONTEXT() 1
-#elif defined(HAVE_SDL2)
-#  include "bzfSDL.h"
-#  define GET_CURRENT_CONTEXT SDL_GL_GetCurrentContext
-#elif defined(HAVE_CGLGETCURRENTCONTEXT)
-#  include <OpenGL/OpenGL.h>
-#  define GET_CURRENT_CONTEXT CGLGetCurrentContext
-#else
-#  include <GL/glx.h>
-#  define GET_CURRENT_CONTEXT glXGetCurrentContext
-#endif
+#include "bzfSDL.h"
+#define GET_CURRENT_CONTEXT SDL_GL_GetCurrentContext
 
 // NOTE: if you're compiler croaks here, then you might want
 //       to find an alternative method for OpenGL context
