@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -28,7 +28,7 @@ public:
 
     void    initJoystick(const char* joystickName);
     bool    joystick() const;
-    void    getJoy(int& x, int& y);
+    void    getJoy(float& x, float& y);
     unsigned long getJoyButtons();
     int     getNumHats();
     void    getJoyHat(int hat, float &hatX, float &hatY);
@@ -37,12 +37,16 @@ public:
     void    setXAxis(const std::string &axis);
     void    setYAxis(const std::string &axis);
 
+    bool    ffHasRumble() const;
+    void    ffRumble(int count, float duration, float strong_motor, float weak_motor = 0.0f);
+
 private:
     SDL_Joystick *joystickID;
     int     joystickButtons;
     int     numHats;
     int     xAxis;
     int     yAxis;
+    bool    hasRumble;
 };
 
 #endif // BZF_SDLJOY_H
