@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,11 +12,16 @@
 
 #include "common.h"
 
-#ifdef HAVE_SDL
 #include <stdlib.h>
 #include <string>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef _WIN32
+#  ifndef S_ISDIR
+#    define S_ISDIR(m) ((m) & _S_IFDIR)
+#  endif
+#endif
+
 
 #include "SDLMedia.h"
 #include "ErrorHandler.h"
@@ -82,11 +87,7 @@ void SDLMedia::setMediaDirectory(const std::string& _dir)
 
 double          SDLMedia::stopwatch(bool start)
 {
-#ifdef HAVE_SDL2
     Uint64 currentTick = SDL_GetPerformanceCounter();
-#else
-    Uint32 currentTick = SDL_GetTicks(); //msec
-#endif
 
     if (start)
     {
@@ -94,20 +95,12 @@ double          SDLMedia::stopwatch(bool start)
         return 0.0;
     }
     if (currentTick >= stopwatchTime)
-#ifdef HAVE_SDL2
         return (double) (currentTick - stopwatchTime) /
                SDL_GetPerformanceFrequency(); // sec
-#else
-        return (double) (currentTick - stopwatchTime) * 0.001; // sec
-#endif
     else
         //Clock is wrapped : happens after 49 days
         //Should be "wrap value" - stopwatchtime. Now approx.
-#ifdef HAVE_SDL2
         return (double) currentTick / SDL_GetPerformanceFrequency();
-#else
-        return (double) currentTick * 0.001;
-#endif
 }
 
 bool            SDLMedia::openAudio()
@@ -372,19 +365,13 @@ float*      SDLMedia::doReadSound(const std::string &filename, int &numFrames,
 
 void SDLMedia::audioDriver(std::string& driverName)
 {
-#ifdef HAVE_SDL2
     const char *driver = SDL_GetCurrentAudioDriver();
     if (driver)
-#else
-    char driver[128];
-    if (SDL_AudioDriverName(driver, sizeof(driver)))
-#endif
         driverName = driver;
     else
         driverName = "audio not available";
 }
 
-#endif //HAVE_SDL
 // Local Variables: ***
 // mode: C++ ***
 // tab-width: 4 ***
