@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -73,11 +73,7 @@ private:
 
     bool        outputBufferEmpty;
 
-#ifdef HAVE_SDL2
     Uint64      stopwatchTime;
-#else
-    Uint32      stopwatchTime;
-#endif
 
     char        cmdQueue[2048]; // space to save temporary command
     int      cmdFill;   // from 0 to cmdFill
