@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2021 Tim Riker
+ * Copyright (c) 1993-2025 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,15 +12,10 @@
 
 #include "SDLPlatformFactory.h"
 #include "SDLMedia.h"
-#ifdef HAVE_SDL2
 #include "SDL2Display.h"
 #include "SDL2Visual.h"
 #include "SDL2Window.h"
-#else
-#include "SDLDisplay.h"
-#endif
 #include "SDLJoystick.h"
-#include "EvdevJoystick.h"
 
 PlatformFactory* PlatformFactory::getInstance()
 {
@@ -68,18 +63,25 @@ BzfMedia* SdlPlatformFactory::createMedia()
 
 BzfJoystick* SdlPlatformFactory::createJoystick()
 {
-    /* Use EvdevJoystick instead of SDLJoystick if we can.
-     * It has minor improvements in axis mapping and joystick
-     * enumeration, but the big selling point so far is that it
-     * supports force feedback.
-     */
-#ifdef HAVE_LINUX_INPUT_H
-    if (EvdevJoystick::isEvdevAvailable())
-        return new EvdevJoystick;
-#endif
-
     return new SDLJoystick;
 }
+
+std::string SdlPlatformFactory::getClipboard()
+{
+    if (SDL_HasClipboardText())
+    {
+        char* clipboard = SDL_GetClipboardText();
+        if (clipboard != nullptr)
+        {
+            const std::string text(clipboard);
+            SDL_free(clipboard);
+            return text;
+        }
+    }
+
+    return std::string();
+}
+
 // Local Variables: ***
 // mode: C++ ***
 // tab-width: 4 ***
